@@ -1,6 +1,6 @@
 package Module::Path;
 # ABSTRACT: get the full path to a locally installed module
-$Module::Path::VERSION = '0.12';
+$Module::Path::VERSION = '0.14';
 use 5.006;
 use strict;
 use warnings;
@@ -46,8 +46,8 @@ sub module_path
         # The previous attempt at this only dealt with the case
         # where the final directory in the path was a symlink,
         # now we're trying to deal with symlinks anywhere in the path.
-        $dir = abs_path($dir);
-        next DIRECTORY unless defined($dir);
+        eval { $dir = abs_path($dir); };
+        next DIRECTORY if $@ || !defined($dir);
 
         $fullpath = $dir.$SEPARATOR.$relpath;
         return $fullpath if -f $fullpath;
@@ -75,8 +75,11 @@ Module::Path - get the full path to a locally installed module
 
 =head1 DESCRIPTION
 
-Module::Path provides a single function, C<module_path()>,
-which will find where a module is installed locally.
+This module provides a single function, C<module_path()>,
+which takes a module name and finds the first directory in your C<@INC> path
+where the module is installed locally.
+It returns the full path to that file, resolving any symlinks.
+It is portable and only depends on core modules.
 
 It works by looking in all the directories in C<@INC>
 for an appropriately named file:
